@@ -10,14 +10,20 @@ import sys
 
 if sys.version_info[0] < 3:
 	# Python 2.
+	unicode = unicode
 	string_types = (basestring,)
 
-	def viewkeys(mapping):
-		return mapping.viewkeys()
+	from itertools import izip_longest
+
+	def iterkeys(mapping):
+		return mapping.iterkeys()
 
 else:
 	# Python 3.
-	string_types = (str,)
+	unicode = str
+	string_types = (unicode,)
 
-	def viewkeys(mapping):
+	from itertools import zip_longest as izip_longest
+
+	def iterkeys(mapping):
 		return mapping.keys()
